==> linuxconf_1.17r5.orig.tar.gz: linuxconf-1.17r5/modules/redhatppp/redhatppp.m <==
extern const char **_dictionary_redhatppp;
#ifndef DICTIONARY_REQUEST
	#define DICTIONARY_REQUEST \
	const char **_dictionary_redhatppp;\
	TRANSLATE_SYSTEM_REQ _dictionary_req_redhatppp("redhatppp",_dictionary_redhatppp,79,0);\
	void dummy_dict_redhatppp(){}
#endif
#ifndef MSG_U
	#define MSG_U(id,m)	_dictionary_redhatppp[id]
	#define MSG_B(id,m,n)	_dictionary_redhatppp[id]
	#define MSG_R(id)	_dictionary_redhatppp[id]
	#define P_MSG_U(id,m)	new_trans_notload(_dictionary_redhatppp,id)
	#define P_MSG_B(id,m,n)	new_trans_notload(_dictionary_redhatppp,id)
	#define P_MSG_R(id)	new_trans_notload(_dictionary_redhatppp,id)
#endif
#define M_DIALOUT	0
#define I_ADDBYLNX	1
#define E_IVLDIP	2
#define P_CONTROLPTP	3
#define T_PPPINTER	4
#define T_SLIPINTER	5
#define T_PLIPINTER	6
#define F_MODEMPORT	7
#define T_HARDWARE	8
#define I_HARDFLOWCTL	9
#define I_ESCAPECHARS	10
#define I_DEFABORT	11
#define I_USERCTL	12
#define F_LINESPEED	13
#define F_PPPOPTIONS	14
#define T_COMMS	15
#define F_MODEMINIT	16
#define F_MODEMDIAL	17
#define F_PHONE	18
#define I_DEBUGCON	19
#define T_CHAT	20
#define F_EXPECT	21
#define F_SEND	22
#define T_NETWORKING	23
#define I_ONBOOT	24
#define I_DEFROUTE	25
#define I_PERSIST	26
#define T_TIMEOUT	27
#define F_NOCON	28
#define F_BROKENCON	29
#define T_MAXPACKET	30
#define F_MRU	31
#define F_MTU	32
#define T_INFREQUENT	33
#define F_LOCALIP	34
#define F_REMOTEIP	35
#define F_NETMASK	36
#define F_MODE	37
#define T_PAP	38
#define F_PAPNAME	39
#define F_SECRET	40
#define B_CONNECT	41
#define X_CONNECT	42
#define B_DISCONNECT	43
#define X_DISCONNECT	44
#define E_MRU	45
#define E_MTU	46
#define E_DISCON	47
#define E_SECRET	48
#define I_USEPAP	49
#define F_LOGIN	50
#define F_PASSWORD	51
#define B_CUSTOMIZE	52
#define X_CUSTOMIZE	53
#define R_PPP	54
#define R_SLIP	55
#define R_PLIP	56
#define T_DEVTYPE	57
#define P_EDITDIALOUT	58
#define T_CONFIGS	59
#define T_PPPSLIPCONF	60
#define T_CONFIGSTATUS	61
#define I_CONNECTED	62
#define I_DIALING	63
#define T_PPPCONCTRL	64
#define I_PPPCONCTRL	65
#define P_CTLDIALOUT	66
#define Q_DOCONN	67
#define I_DOCONN	68
#define Q_DODISCONN	69
#define I_DODISCONN	70
#define I_REMOVINGPTP	71
#define M_dialout	72
#define M_PPPCTRL	73
#define T_USAGE	74
#define F_CONFIGNAME	75
#define F_LINKSETUP	76
#define I_LINKSETUP	77
#define I_PEERDNS	78

==> linuxconf_1.26r4.orig.tar.gz: linuxconf-1.26r4/modules/redhatppp/redhatppp.m <==
extern const char **_dictionary_redhatppp;
#ifndef DICTIONARY_REQUEST
	#define DICTIONARY_REQUEST \
	const char **_dictionary_redhatppp;\
	TRANSLATE_SYSTEM_REQ _dictionary_req_redhatppp("redhatppp",_dictionary_redhatppp,84,0);\
	void dummy_dict_redhatppp(){}
#endif
#ifndef MSG_U
	#define MSG_U(id,m)	_dictionary_redhatppp[id]
	#define MSG_B(id,m,n)	_dictionary_redhatppp[id]
	#define MSG_R(id)	_dictionary_redhatppp[id]
	#define P_MSG_U(id,m)	new_trans_notload(_dictionary_redhatppp,id)
	#define P_MSG_B(id,m,n)	new_trans_notload(_dictionary_redhatppp,id)
	#define P_MSG_R(id)	new_trans_notload(_dictionary_redhatppp,id)
#endif
#define M_DIALOUT	0
#define I_ADDBYLNX	1
#define E_IVLDIP	2
#define P_CONTROLPTP	3
#define T_PPPINTER	4
#define T_SLIPINTER	5
#define T_PLIPINTER	6
#define F_MODEMPORT	7
#define T_HARDWARE	8
#define I_HARDFLOWCTL	9
#define I_ESCAPECHARS	10
#define I_DEFABORT	11
#define I_USERCTL	12
#define F_LINESPEED	13
#define F_PPPOPTIONS	14
#define T_COMMS	15
#define F_MODEMINIT	16
#define F_MODEMDIAL	17
#define F_PHONE	18
#define I_DEBUGCON	19
#define T_CHAT	20
#define F_EXPECT	21
#define F_SEND	22
#define T_NETWORKING	23
#define I_ONBOOT	24
#define I_DEFROUTE	25
#define I_PERSIST	26
#define T_TIMEOUT	27
#define F_NOCON	28
#define F_BROKENCON	29
#define T_MAXPACKET	30
#define F_MRU	31
#define F_MTU	32
#define T_INFREQUENT	33
#define F_LOCALIP	34
#define F_REMOTEIP	35
#define F_NETMASK	36
#define F_MODE	37
#define T_PAP	38
#define F_PAPNAME	39
#define F_SECRET	40
#define B_CONNECT	41
#define X_CONNECT	42
#define B_DISCONNECT	43
#define X_DISCONNECT	44
#define E_MRU	45
#define E_MTU	46
#define E_DISCON	47
#define E_SECRET	48
#define I_USEPAP	49
#define F_LOGIN	50
#define F_PASSWORD	51
#define B_CUSTOMIZE	52
#define X_CUSTOMIZE	53
#define R_PPP	54
#define R_SLIP	55
#define R_PLIP	56
#define T_DEVTYPE	57
#define P_EDITDIALOUT	58
#define T_CONFIGS	59
#define T_PPPSLIPCONF	60
#define T_CONFIGSTATUS	61
#define I_CONNECTED	62
#define I_DIALING	63
#define T_PPPCONCTRL	64
#define I_PPPCONCTRL	65
#define P_CTLDIALOUT	66
#define Q_DOCONN	67
#define I_DOCONN	68
#define Q_DODISCONN	69
#define I_DODISCONN	70
#define I_REMOVINGPTP	71
#define M_dialout	72
#define M_PPPCTRL	73
#define T_USAGE	74
#define F_CONFIGNAME	75
#define F_LINKSETUP	76
#define I_LINKSETUP	77
#define I_PEERDNS	78
#define F_SECRET2	79
#define E_PASSMATCH	80
#define F_PASSWORD2	81
#define I_FIREWALL	82
#define I_PPPDEVDESC	83
